import { Resource } from 'aws-cdk-lib';
import { Rule } from 'aws-cdk-lib/aws-events';
import { AddToResourcePolicyResult, Grant, IGrantable, PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { BucketPolicy, CfnBucket, CfnBucketProps, EventType, IBucket, IBucketNotificationDestination, NotificationKeyFilter, OnCloudTrailBucketEventOptions, TransferAccelerationUrlOptions, VirtualHostedStyleUrlOptions } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * Configuration for objects bucket
 */
export interface RawBucketProps extends CfnBucketProps {
}
export declare class RawBucket extends Resource implements IBucket {
    private readonly _cdkBucket;
    policy?: BucketPolicy;
    readonly resource: CfnBucket;
    readonly bucketArn: string;
    readonly bucketName: string;
    readonly bucketWebsiteUrl: string;
    readonly bucketWebsiteDomainName: string;
    readonly bucketDomainName: string;
    readonly bucketDualStackDomainName: string;
    readonly bucketRegionalDomainName: string;
    readonly encryptionKey?: IKey | undefined;
    readonly isWebsite?: boolean | undefined;
    addEventNotification: {
        (event: EventType, dest: IBucketNotificationDestination, ...filters: NotificationKeyFilter[]): void;
    };
    addObjectCreatedNotification: {
        (dest: IBucketNotificationDestination, ...filters: NotificationKeyFilter[]): void;
    };
    addObjectRemovedNotification: {
        (dest: IBucketNotificationDestination, ...filters: NotificationKeyFilter[]): void;
    };
    arnForObjects: {
        (keyPattern: string): string;
    };
    enableEventBridgeNotification: {
        (): void;
    };
    grantDelete: {
        (identity: IGrantable, objectsKeyPattern?: any): Grant;
    };
    grantPublicAccess: {
        (keyPrefix?: string, ...allowedActions: string[]): Grant;
    };
    grantPut: {
        (identity: IGrantable, objectsKeyPattern?: any): Grant;
    };
    grantPutAcl: {
        (identity: IGrantable, objectsKeyPattern?: string): Grant;
    };
    grantRead: {
        (identity: IGrantable, objectsKeyPattern?: any): Grant;
    };
    grantReadWrite: {
        (identity: IGrantable, objectsKeyPattern?: any): Grant;
    };
    grantWrite: {
        (identity: IGrantable, objectsKeyPattern?: any): Grant;
    };
    onCloudTrailEvent: {
        (id: string, options?: OnCloudTrailBucketEventOptions): Rule;
    };
    onCloudTrailPutObject: {
        (id: string, options?: OnCloudTrailBucketEventOptions): Rule;
    };
    onCloudTrailWriteObject: {
        (id: string, options?: OnCloudTrailBucketEventOptions): Rule;
    };
    s3UrlForObject: {
        (key?: string): string;
    };
    transferAccelerationUrlForObject: {
        (key?: string, options?: TransferAccelerationUrlOptions): string;
    };
    urlForObject: {
        (key?: string): string;
    };
    virtualHostedUrlForObject: {
        (key?: string, options?: VirtualHostedStyleUrlOptions): string;
    };
    /**
       * Creates a new instance of the ReplicatedBucket class.
       *
       * @param scope A CDK Construct that will serve as this stack's parent in the construct tree.
       * @param id A name to be associated with the stack and used in resource naming. Must be unique
       * within the context of 'scope'.
       * @param props Arguments related to the configuration of the resource.
       */
    constructor(scope: Construct, id: string, props?: RawBucketProps);
    addToResourcePolicy(permission: PolicyStatement): AddToResourcePolicyResult;
}
