import { Stack, StackProps } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { FlowLogFormat } from '../services/ec2/constructs/flow-log';
import { Database } from '../services/glue/constructs/database';
import { AlbLogsBucket } from '../services/s3/patterns/alb-logs-bucket';
import { CloudfrontLogsBucket } from '../services/s3/patterns/cloudfront-logs-bucket';
import { CloudtrailBucket } from '../services/s3/patterns/cloudtrail-bucket';
import { FlowLogsBucket } from '../services/s3/patterns/flow-logs-bucket';
import { S3AccessLogsBucket } from '../services/s3/patterns/s3-access-logs-bucket';
import { SesLogsBucket } from '../services/s3/patterns/ses-logs-bucket';
import { WafLogsBucket } from '../services/s3/patterns/waf-logs-bucket';
/**
 * Configuration for the demo service stack.
 */
export interface AwsLoggingStackProps extends StackProps {
    readonly albLogsBucket?: AlbLogsBucket;
    readonly cloudfrontLogsBucket?: CloudfrontLogsBucket;
    readonly cloudtrailLogsBucket?: CloudtrailBucket;
    readonly databaseName?: string;
    readonly flowLogsBucket?: FlowLogsBucket;
    readonly flowLogsFormat?: FlowLogFormat;
    readonly friendlyQueryNames?: boolean;
    readonly sesLogsBucket?: SesLogsBucket;
    readonly standardizeNames?: boolean;
    readonly wafLogsBucket?: WafLogsBucket;
}
/**
 * Creates a demo web service running in Fargate that is accessible through an application load balancer.
 * The demo service serves a generic "Welcome to nginx" page.
 *
 * The service can be accessed remotely using ECS Exec. For details see the documentation at:
 * https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-exec.html#ecs-exec-running-commands
 */
export declare class AwsLoggingStack extends Stack {
    readonly databaseName: string;
    readonly flowLogsFormat: FlowLogFormat;
    readonly friendlyQueryNames?: boolean;
    readonly standardizeNames: boolean;
    readonly albLogsBucket: AlbLogsBucket;
    readonly cloudfrontLogsBucket: CloudfrontLogsBucket;
    readonly cloudtrailLogsBucket: CloudtrailBucket;
    readonly database: Database;
    readonly flowLogsBucket: FlowLogsBucket;
    readonly s3AccessLogsBucket: S3AccessLogsBucket;
    readonly sesLogsBucket: SesLogsBucket;
    readonly wafLogsBucket: WafLogsBucket;
    constructor(scope: Construct, id: string, props?: AwsLoggingStackProps);
}
